@@ -20,17 +20,17 @@
 #' @examples
 #' library(randomForest)
 #' data(iris)
-#' fit <- randomForest(Species ~ ., iris)
+#' fit = randomForest(Species ~ ., iris)
 #' variable_importance(fit, nperm = 2, data = iris)
 #' @export
-variable_importance <- function(fit, vars, interaction, nperm, data, ...)
+variable_importance = function(fit, vars, interaction, nperm, data, ...)
   UseMethod("variable_importance")
 #' @export
-variable_importance.randomForest <- function(fit, vars,
+variable_importance.randomForest = function(fit, vars,
   interaction = FALSE, nperm = 100L, data, ...) {
 
-  vars <- if (missing(vars)) attributes(fit$terms)$term.labels else vars
-  args <- list(
+  vars = if (missing(vars)) attributes(fit$terms)$term.labels else vars
+  args = list(
     "data" = data,
     "vars" = vars,
     "y" =  if (!is.null(fit$terms)) deparse(attr(fit$terms, "variables")[[2]]) else colnames(data)[which(sapply(data, function(x) all.equal(x, fit$y, check.attributes = FALSE)) == "TRUE")],
@@ -41,28 +41,28 @@ variable_importance.randomForest <- function(fit, vars,
   )
   
   if (length(vars) > 1L & !interaction)
-    imp <- sapply(vars, function(x) {    
-      args$vars <- x
+    imp = sapply(vars, function(x) {    
+      args$vars = x
       do.call("permutationImportance", args)
     }, simplify = FALSE)
   else
-    imp <- do.call("permutationImportance", args)
+    imp = do.call("permutationImportance", args)
 
-  attr(imp, "class") <- c("imp", class(imp))
-  attr(imp, "target") <- args$y
-  attr(imp, "nperm") <- nperm
+  attr(imp, "class") = c("imp", class(imp))
+  attr(imp, "target") = args$y
+  attr(imp, "nperm") = nperm
   imp
 }
 #' @export
-variable_importance.RandomForest <- function(fit, vars,
+variable_importance.RandomForest = function(fit, vars,
   interaction = FALSE, nperm = 100L, data = NULL, ...) {
 
-  target <- names(get("response", fit@data@env))
-  data <- data.frame(get("input", fit@data@env),
+  target = names(get("response", fit@data@env))
+  data = data.frame(get("input", fit@data@env),
     get("response", fit@data@env))
-  vars <- if (missing(vars)) colnames(get("input", fit@data@env)) else vars
+  vars = if (missing(vars)) colnames(get("input", fit@data@env)) else vars
 
-  args <- list(
+  args = list(
     "data" = data,
     "y" = target,
     "vars" = vars,
@@ -73,27 +73,27 @@ variable_importance.RandomForest <- function(fit, vars,
   )
   
   if (length(vars) > 1L & !interaction)
-    imp <- sapply(vars, function(x) {
-      args$vars <- x
+    imp = sapply(vars, function(x) {
+      args$vars = x
       do.call("permutationImportance", args)
     }, simplify = FALSE)
   else
-    imp <- do.call("permutationImportance", args)
+    imp = do.call("permutationImportance", args)
 
-  attr(imp, "class") <- c("imp", class(imp))
-  attr(imp, "target") <- args$y
-  attr(imp, "nperm") <- nperm
+  attr(imp, "class") = c("imp", class(imp))
+  attr(imp, "target") = args$y
+  attr(imp, "nperm") = nperm
   imp
 }
 #' @export
-variable_importance.rfsrc <- function(fit, vars,
+variable_importance.rfsrc = function(fit, vars,
   interaction = FALSE, nperm = 100, data = NULL, ...) {
 
-  data <- data.frame(fit$xvar, fit$yvar)
-  names(data)[(ncol(fit$xvar) + 1):ncol(data)] <- fit$yvar.names
-  vars <- if (missing(vars)) colnames(fit$xvar) else vars
+  data = data.frame(fit$xvar, fit$yvar)
+  names(data)[(ncol(fit$xvar) + 1):ncol(data)] = fit$yvar.names
+  vars = if (missing(vars)) colnames(fit$xvar) else vars
   
-  args <- list(
+  args = list(
     "data" = data,
     "vars" = vars,
     "y" = fit$yvar.names,
@@ -104,24 +104,24 @@ variable_importance.rfsrc <- function(fit, vars,
   )
 
   if (length(vars) > 1L & !interaction)
-    imp <- sapply(vars, function(x) {
-      args$vars <- x
+    imp = sapply(vars, function(x) {
+      args$vars = x
       do.call("permutationImportance", args)
     }, simplify = FALSE)
   else
-    imp <- do.call("permutationImportance", args)
+    imp = do.call("permutationImportance", args)
 
-  attr(imp, "class") <- c("imp", class(imp))
-  attr(imp, "target") <- args$y
-  attr(imp, "nperm") <- nperm
+  attr(imp, "class") = c("imp", class(imp))
+  attr(imp, "target") = args$y
+  attr(imp, "nperm") = nperm
   imp
 }
 
 #' @export
-variable_importance.ranger <- function(fit, vars, interaction = FALSE, nperm = 100,
+variable_importance.ranger = function(fit, vars, interaction = FALSE, nperm = 100,
   data, ...) {
 
-  args <- list(
+  args = list(
     "data" = data,
     "vars" = vars,
     "y" = names(data)[!names(data) %in% fit$forest$independent.variable.names],
@@ -132,15 +132,15 @@ variable_importance.ranger <- function(fit, vars, interaction = FALSE, nperm = 1
   )
   
   if (length(vars) > 1L & !interaction)
-    imp <- sapply(vars, function(x) {
-      args$vars <- x
+    imp = sapply(vars, function(x) {
+      args$vars = x
       do.call("permutationImportance", args)
     }, simplify = FALSE)
   else
-    imp <- do.call("permutationImportance", args)
+    imp = do.call("permutationImportance", args)
 
-  attr(imp, "class") <- c("imp", class(imp))
-  attr(imp, "target") <- args$y
-  attr(imp, "nperm") <- nperm
+  attr(imp, "class") = c("imp", class(imp))
+  attr(imp, "target") = args$y
+  attr(imp, "nperm") = nperm
   imp  
 }
