@@ -15,21 +15,21 @@
 #' @examples
 #' library(randomForest)
 #' 
-#' fit <- randomForest(hp ~ ., mtcars, proximity = TRUE)
+#' fit = randomForest(hp ~ ., mtcars, proximity = TRUE)
 #' extract_proximity(fit)
 #'
-#' fit <- randomForest(Species ~ ., iris, proximity = TRUE)
+#' fit = randomForest(Species ~ ., iris, proximity = TRUE)
 #' extract_proximity(fit)
 #' @export
-extract_proximity <- function(fit, newdata) UseMethod("extract_proximity")
+extract_proximity = function(fit, newdata) UseMethod("extract_proximity")
 #' @export
-extract_proximity.randomForest <- function(fit, newdata = NULL, ...) {
+extract_proximity.randomForest = function(fit, newdata = NULL, ...) {
   if (!is.null(newdata)) {
-    pred <- predict(fit, newdata = newdata, proximity = TRUE, ...)
+    pred = predict(fit, newdata = newdata, proximity = TRUE, ...)
     if (!is.null(pred$oob.prox))
-      out <- pred$oob.prox
+      out = pred$oob.prox
     else if (!is.null(pred$prox))
-      out <- pred$prox
+      out = pred$prox
     else stop("not sure what is up") 
   } else {
     if (is.null(fit$proximity))
@@ -38,13 +38,13 @@ extract_proximity.randomForest <- function(fit, newdata = NULL, ...) {
   }
 }
 #' @export
-extract_proximity.RandomForest <- function(fit, newdata = NULL, ...) {
+extract_proximity.RandomForest = function(fit, newdata = NULL, ...) {
   party::proximity(fit, newdata, ...)
 }
 #' @export
-extract_proximity.rfsrc <- function(fit, newdata = NULL, ...) {
+extract_proximity.rfsrc = function(fit, newdata = NULL, ...) {
   if (!is.null(newdata)) {
-    pred <- predict(fit, newdata = newdata, proximity = TRUE, ...)
+    pred = predict(fit, newdata = newdata, proximity = TRUE, ...)
     pred$prox
   } else {
     if (is.null(fit$proximity))
@@ -54,15 +54,15 @@ extract_proximity.rfsrc <- function(fit, newdata = NULL, ...) {
 }
 
 #' @export
-extract_proximity.ranger <- function(fit, newdata, ...) {
-  pred <- predict(fit, newdata, type = "terminalNodes")$predictions
-  prox <- matrix(NA, nrow(pred), nrow(pred))
-  ntree <- ncol(pred)
-  n <- nrow(prox)
+extract_proximity.ranger = function(fit, newdata, ...) {
+  pred = predict(fit, newdata, type = "terminalNodes")$predictions
+  prox = matrix(NA, nrow(pred), nrow(pred))
+  ntree = ncol(pred)
+  n = nrow(prox)
 
   for (i in 1:n) {
     for (j in 1:n) {
-      prox[i, j] <- sum(pred[i, ] == pred[j, ])
+      prox[i, j] = sum(pred[i, ] == pred[j, ])
     }
   }
 
